pub struct ColoredNoise<S: Scalar> { /* private fields */ }Expand description
Spatially colored (correlated) noise.
Noise at nearby points is correlated with correlation function: C(|x - x’|) = exp(-|x - x’| / λ)
where λ is the correlation length.
Implementations
Sourceimpl<S: Scalar> ColoredNoise<S>
impl<S: Scalar> ColoredNoise<S>
Sourcepub fn new(
dx: S,
correlation_length: S,
n_points: usize,
seed: Option<u64>,
) -> Result<Self, String>
pub fn new( dx: S, correlation_length: S, n_points: usize, seed: Option<u64>, ) -> Result<Self, String>
Create colored noise generator.
Arguments
dx- Spatial grid spacingcorrelation_length- Noise correlation lengthn_points- Number of spatial grid pointsseed- Optional random seed
Returns an error if the resulting correlation matrix is not positive definite or is ill-conditioned for the given parameters.